==> hrin_msb-0.1.1-py3-none-any.whl: msb_core/testing/api_test.py <==
from os import environ

from rest_framework.test import APILiveServerTestCase

from ._core import (ApiTestResult, TestConfig, LiveServerThreadWithReuse)


class ApiTest(APILiveServerTestCase):
	port = 8000
	server_thread_class = LiveServerThreadWithReuse

	_app_label: str = 'auth'
	_api_version: int = 1
	__auth_tokens: dict = dict()
	_api_endpoints: dict = {}

	def url(self, name: str):
		return self._api_endpoints.get(name)

	def setUp(self) -> None:
		self._authenticate(self.config.auth_credentials)

	@property
	def config(self):
		return TestConfig()

	@property
	def access_token(self):
		return self.__auth_tokens.get('access')

	@property
	def is_authenticated(self):
		return self.access_token not in ['', None]

	@property
	def api_test_result(self):
		return ApiTestResult

	def __log_api_request(self, **kwargs):
		if environ.get('ENVIRONMENT') == 'local':
			logstr = "{sep}Request: {method} {url}\nPayload: {data}\nOptions: {opt}\nResponse: {result}\n{sep}".format(
				sep=f"{'=' * 100}\n", method=kwargs.get('method').upper(), url=kwargs.get('request_url'),
				data=kwargs.get('data'), result=kwargs.get('response'), opt=kwargs.get('opt')
			)
			print(logstr)

	def __make_api_request(self, method='post', endpoint: str = '', data: dict = None, _func=None, **opt) -> ApiTestResult:
		data = dict() if data is None else data
		result = dict()
		try:
			extra_headers = opt.get('headers') if isinstance(opt.get('headers'), dict) else {}
			request_headers = {**self.config.default_headers, **extra_headers}
			request_url = self.config.make_url(app_label=self._app_label, api_version=self._api_version, endpoint=endpoint)

			if self.access_token:
				self.client.credentials(HTTP_AUTHORIZATION=f'Bearer {self.access_token}')

			handler_func = _func if callable(_func) else self.client.post
			api_response = handler_func(request_url, data, 'json', **request_headers)

			if api_response.headers.get('Content-Type') == self.config.request_content_type:
				result = api_response.json()
			else:
				result = dict(body=api_response.getvalue())
		except Exception as e:
			pass
		finally:
			self.__log_api_request(method=method, request_url=request_url, data=data, opt=opt, response=result)
			result = ApiTestResult(**result)

		# return only the data section of the api response, unless specifically asked for
		return result

	def _authenticate(self, auth_credentials: dict = None) -> None:
		if self.is_authenticated:
			return
		auth_result = self.api_post(self.config.auth_url, payload=auth_credentials)
		if self.assertEquals(list(auth_result.data.keys()), ['refresh', 'access']):
			self.__auth_tokens = dict(auth_result.data)

	def api_get(self, endpoint: str = '', payload: dict = None, **opt) -> ApiTestResult:
		return self.__make_api_request('get', endpoint, payload, _func=self.client.get, **opt)

	def api_post(self, endpoint: str = '', payload: dict = None, **opt) -> ApiTestResult:
		return self.__make_api_request('post', endpoint, payload, _func=self.client.post, **opt)

	def api_put(self, endpoint: str = '', payload: dict = None, **opt) -> ApiTestResult:
		return self.__make_api_request('put', endpoint, payload, _func=self.client.put, **opt)

	def api_delete(self, endpoint: str = '', payload: dict = None, **opt) -> ApiTestResult:
		return self.__make_api_request('delete', endpoint, payload, _func=self.client.delete, **opt)

==> hrin_msb-0.1.3-py3-none-any.whl: msb_core/testing/api_test.py <==
from os import environ

from rest_framework.test import APILiveServerTestCase

from ._core import (ApiTestResult, TestConfig, LiveServerThreadWithReuse)


class ApiTest(APILiveServerTestCase):
	port = 8000
	server_thread_class = LiveServerThreadWithReuse

	_api_version: int = 1
	__auth_tokens: dict = dict()
	_api_endpoints: dict = {}

	def url(self, name: str):
		return self._api_endpoints.get(name)

	def setUp(self) -> None:
		self._authenticate(self.config.auth_credentials)

	@property
	def config(self):
		return TestConfig()

	@property
	def access_token(self):
		return self.__auth_tokens.get('access')

	@property
	def is_authenticated(self):
		return self.access_token not in ['', None]

	@property
	def api_test_result(self):
		return ApiTestResult

	def __log_api_request(self, **kwargs):
		if environ.get('ENVIRONMENT') == 'local':
			logstr = "{sep}Request: {method} {url}\nPayload: {data}\nOptions: {opt}\nResponse: {result}\n{sep}".format(
				sep=f"{'=' * 100}\n", method=kwargs.get('method').upper(), url=kwargs.get('request_url'),
				data=kwargs.get('data'), result=kwargs.get('response'), opt=kwargs.get('opt')
			)
			print(logstr)

	def __make_api_request(self, method='post', endpoint: str = '', data: dict = None, _func=None, **opt) -> ApiTestResult:
		data = dict() if data is None else data
		result = dict()
		try:
			extra_headers = opt.get('headers') if isinstance(opt.get('headers'), dict) else {}
			request_headers = {**self.config.default_headers, **extra_headers}
			request_url = self.config.make_url(api_version=self._api_version, endpoint=endpoint)

			if self.access_token:
				self.client.credentials(HTTP_AUTHORIZATION=f'Bearer {self.access_token}')

			handler_func = _func if callable(_func) else self.client.post
			api_response = handler_func(request_url, data, 'json', **request_headers)

			if api_response.headers.get('Content-Type') == self.config.request_content_type:
				result = api_response.json()
			else:
				result = dict(body=api_response.getvalue())
		except Exception as e:
			pass
		finally:
			self.__log_api_request(method=method, request_url=request_url, data=data, opt=opt, response=result)
			result = ApiTestResult(**result)

		# return only the data section of the api response, unless specifically asked for
		return result

	def _authenticate(self, auth_credentials: dict = None) -> None:
		if self.is_authenticated:
			return
		auth_result = self.api_post(self.config.auth_url, payload=auth_credentials)
		if self.assertEquals(list(auth_result.data.keys()), ['refresh', 'access']):
			self.__auth_tokens = dict(auth_result.data)

	def api_get(self, endpoint: str = '', payload: dict = None, **opt) -> ApiTestResult:
		return self.__make_api_request('get', endpoint, payload, _func=self.client.get, **opt)

	def api_post(self, endpoint: str = '', payload: dict = None, **opt) -> ApiTestResult:
		return self.__make_api_request('post', endpoint, payload, _func=self.client.post, **opt)

	def api_put(self, endpoint: str = '', payload: dict = None, **opt) -> ApiTestResult:
		return self.__make_api_request('put', endpoint, payload, _func=self.client.put, **opt)

	def api_delete(self, endpoint: str = '', payload: dict = None, **opt) -> ApiTestResult:
		return self.__make_api_request('delete', endpoint, payload, _func=self.client.delete, **opt)
